/* 
Compare styles in mi setting.
MI_Styles.do  ESH 20jan2010
from Mi_exampl1.do TBN
We also demonstrate -snapshot- and -capture noisily-
*/

clear
version 11

snapshot erase _all

* Analyze the incomplete data set using complete cases only (N = 36)
use automiss.dta, clear
snapshot save, label("original")
describe, short
*regress gp100m weight displacement gear_ratio length foreign
*estimates store withmissing

* Display the missingness patterns
misstable patterns, frequency
misstable patterns weight length displacement price headroom trunk turn gear_ratio gp100m, frequency

// Weight and Displacement seem to have the most missing data

/* Stata has four MI data styles: 
	Full,long&separate (flongsep): 
		stores full copy of each imputed data set; 
		useful for imported or large data sets
	Full long (flong): 
		Keeps full copy of each imputed data set stacked in one Stata dataset. 
		Best for imported data sets. 
	Marginal Long (mlong): 
		Keeps the original data set plus only imputed observations; 
		use when manipulating observations
	Wide (wide): 
		Stores copies of imputed variables; 
		useful when manipulating variables. 
		
	mlong and wide are equally recommended by Stata Corp
*/

// Length weight and displacement need to be imputed and so are registered to be imputed
// Regular variables have no missing values, but contribute information to the multiple imputations
	
mi query
	
* Tell Stata we will generate 20 imputations and which variables need to be imputed and which do not
capture noisily !erase *automiss_sep.dta
mi set flongsep automiss_sep
mi register imputed weight length displacement
mi register regular price mpg headroom trunk turn gear_ratio foreign gp100m
mi query
capture noisily mi describe

* Generate 20 imputations 
mi impute mvn weight length displacement = price headroom trunk turn gear_ratio gp100m, ///
add(20) replace rseed(3593) savewlf(wlf, replace) 
snapshot save, label("flongsep")
mi query
mi describe
snapshot restore 1

capture noisily mi convert flong
snapshot restore 2
mi convert flong
snapshot save, label("flong")
mi query
mi describe

mi convert mlong
snapshot save, label("mlong")
mi query
mi describe

mi convert wide
snapshot save, label("wide")
mi query
mi describe

snapshot list

* Run the analysis on the imputed data sets
mi estimate, saving(myest, replace): regress gp100m weight displacement gear_ratio length foreign
estimates store mi
mi test weight
mi test weight length
mi estimate (diff: _b[length]-_b[weight]) using myest
mi testtransform diff
mi estimate (rdiff: _b[length]/_b[weight]-1) using myest
mi testtransform rdiff

exit

describe, short
char list
