/* 
New_Old.do  ESH 20jan2010
From SF Stata Training Oct 2, 2009
Additional helpful commands
*/

clear
version 11
pause off 

// Competing Risks regression
webuse hiv_si
codebook
capture noisily stset
stset time , failure(status==2)
stcrreg ccr5 , compete(status==1)
stcurve, cif at1(ccr5=0) at2(ccr5=1) range(0 13) name("stcurve_failure_SI")

streset , failure(status==1) // AIDS is primary outcome
stcrreg ccr5 , compete(status==2)
stcurve, cif at1(ccr5=0) at2(ccr5=1) range(0 13) name("stcurve_failure_AIDS")
pause // type -end- to resume

// Additions to -xtmixed-: unstructured correlation structure
webuse childweight
codebook
compress
gen bwtkg = brthwt / 1000
// Residual Covariance Structure - random slopes for simple model
xtmixed weight c.age##c.age bwtkg girl || id: age, cov(unstr) mle
estimates store simple

// Residual Covariance Structure - random slopes spearating boys&girls
xtmixed weight c.age##c.age bwtkg girl || id: age, cov(unstr) resid(indep , by(girl)) mle
estimates store heterosked
lrtest simple heterosked, stat
pause // type -end- to resume

// two random effects
xtmixed weight c.age##c.age bwtkg girl || id: age girl, nocons cov(unstr) resid(indep, by(girl)) mle

// Documented Changes from 10 to 11 
. help whatsnew10to11
pause // type -end- to resume

// A user-written command for logistic regression via penalized ML
. findit firthlogit
pause
findit exact logistic
pause

// More about MI -- presentation at the 2009 UK users' group
* http://ideas.repec.org/s/boc/usug09.html
* http://ideas.repec.org/p/boc/usug09/13.html

// Useful commands from Yulia Marchenko at StataCorp.
findit marchenko
pause

// Combining mi with other prefix commands:
* mi & svy
* mi & stset
* Interactions with mi
* soft and hard missing values

// Summary storage requirment for the mi styles
/*
DSN/mi style				obs		vars	size
automiss.dta / none			    74	13		   4,070
automiss_sep.dta / flongsep  21*74	15		21*4,218
flong						 1,554	16		 101,010 = 21*4,810
mlong						   834	16		  54,210
wide						    74	74		  22,348

flong:  obs  1554 = 21*74
mlong:  obs  834 = 20*38+74 [74-36=38 obs w/ some missing]
wide :  vars 13+ 3*20 + 1 [3 variables w/ missing; _mi_miss]
*/

// Useful commands
help db
pause
help doedit
pause
* cmdlog using /*fn.do*/
help cmdlog
pause
help adoupdate
pause
*adoupdate, update 
*adoupdate, update all

// Adding navigation in Acrobat Reader version 9:
* Tools > Custimize Toolbars...  > Page Navigation Toolbar 
* Check the "Previous View" and "Next View" checkbxes
* Cilck on the OK button

// Modified commands
help merge
pause
/* 1:1, 1:m, m:1, on a primary key varlist. */
/* no need to sort */
help append
pause
/* multiple datasets, some may not exist */
/* append using data2, generate(newvar) */

exit

